function [A,b] = MKP(P,E,GammaD,GammaN,EYoung,nu,f,uD,gN)

%       [A,b] = MKP(P,E,GammaD,GammaN,tau,f,uD,gN)
%       Sestavi soustavu metodou konecnych prvku
%       pro okrajovou ulohu 2d lin. pruznosti
%       -div[sigma(u(x))] = f(x) v Omega
%                           u(x) = uD(x) na GammaD
%               sigma(u(x))*n(x) = gN(x) na GammaN
%       + podm. prechodu
%       P ... souradnice uzlu (matice 2xn)
%       E ... indexy uzlu trojuhelnikove site (matice 3xm)
%       GammaD ... indexy Dirichletovych uzlu (vektor nD)
%       GammaN ... dvojice indexu Neumannovych uzlu (matice 2xmN)
%       EYoung,nu ... Young. modul pruznosti, Poissonovo cislo
%       f ... po trojuhelnicich konst. (vektory 2*m)
%       uD ... po Dir. useckach afinni (vektor 2*nD)
%       gN ... po Neum. useckach konst. (vektor 2*mN)


n = size(P,2);
A = sparse(2*n,2*n);
b = zeros(2*n,1);

m = size(E,2);
nD = length(GammaD);
mN = size(GammaN,2);

% Lameho koeficienty
lambda = EYoung*nu / ((1+nu)*(1-2*nu));
mu = EYoung/(1+nu);

% vypocet objemovych integralu
for k=1:m
    ek = E(:,k);
    Pk = P(:,ek);
    
    Ak = alok_elast(Pk,lambda,mu);
    
    fk = f(:,k);
    bk = blok_id(Pk,fk);
    
    A([ek;n+ek],[ek;n+ek]) = A([ek;n+ek],[ek;n+ek]) + Ak;
    b([ek;n+ek]) = b([ek;n+ek]) + bk;
end

% vypocet hranicnich (Neumannova okr. pod.) integralu
for k=1:mN
    ek = GammaN(:,k);
    Pk = P(:,ek);
    
    gNk = gN(:,k);
    bk = blok_bound_id(Pk,gNk);
    
    b([ek;n+ek]) = b([ek;n+ek]) + bk;
end

% nehomogenni Dirichletovy podminky
for k=1:nD
    % prvni slozky
    idxk = GammaD(k);
    a = A(idxk,idxk);
    A(idxk,:) = 0;
    A(idxk,idxk) = a;
    b(idxk) = uD(1,k) * a;

    % druhe slozky
    idxk = n+GammaD(k);
    a = A(idxk,idxk);
    A(idxk,:) = 0;
    A(idxk,idxk) = a;
    b(idxk) = uD(2,k) * a;
end
